"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DataProvider = void 0;
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importDefault(require("react"));
const tango_boot_1 = require("@music163/tango-boot");
const helpers_1 = require("../helpers");
const defaultShouldLoadData = () => true;
/**
 * 数据提供者
 */
class DataProviderBase extends react_1.default.Component {
    constructor() {
        super(...arguments);
        this.state = {
            data: undefined,
            loading: false,
            error: undefined,
        };
    }
    load() {
        const { shouldLoadData, loadData, payload } = this.props;
        const shouldLoad = shouldLoadData(payload);
        if (shouldLoad && (0, helpers_1.isFunction)(loadData)) {
            const ret = loadData(payload, { signal: this.controller.signal });
            // 如果无返回或者不是 promise 对象
            if ((0, helpers_1.isNil)(ret) || !ret.then) {
                this.updateData(ret);
                return;
            }
            this.setState({ loading: true });
            ret
                .then((data) => {
                this.updateData(data);
            })
                .catch((error) => {
                this.setState({ error });
            })
                .finally(() => {
                this.setState({ loading: false });
            });
        }
    }
    componentDidMount() {
        this.controller = new AbortController();
        this.load();
    }
    componentDidUpdate(prevProps) {
        if (!(0, helpers_1.isDeepEquals)(prevProps.payload, this.props.payload)) {
            this.load();
        }
    }
    componentWillUnmount() {
        this.controller.abort();
    }
    render() {
        const { children } = this.props;
        const { data, loading, error } = this.state;
        return react_1.default.createElement(react_1.default.Fragment, null, children === null || children === void 0 ? void 0 : children(data, { loading, error }));
    }
    updateData(data) {
        // const { model, formatter, onData } = this.props;
        const { formatter, onData } = this.props;
        if ((0, helpers_1.isFunction)(formatter)) {
            data = formatter(data);
        }
        this.setState({ data });
        if ((0, helpers_1.isFunction)(onData)) {
            onData(data);
        }
    }
}
DataProviderBase.defaultProps = {
    shouldLoadData: defaultShouldLoadData,
};
exports.DataProvider = react_1.default.forwardRef((props, ref) => {
    return (react_1.default.createElement(tango_boot_1.Collector, Object.assign({}, props, { render: ({ setValue, ref: tangoRef }) => {
            return (react_1.default.createElement(DataProviderBase, Object.assign({}, props, { onData: (data) => {
                    setValue(data);
                }, ref: (0, helpers_1.mergeRefs)(ref, tangoRef) })));
        } })));
});
exports.DataProvider.displayName = 'DataProvider';
