"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createContext = exports.mergeRefs = void 0;
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importDefault(require("react"));
function mergeRefs(...refs) {
    const filteredRefs = refs.filter(Boolean);
    if (!filteredRefs.length)
        return null;
    if (filteredRefs.length === 0)
        return filteredRefs[0];
    return (instance) => {
        for (const ref of filteredRefs) {
            if (typeof ref === 'function') {
                ref(instance);
            }
            else if (ref) {
                ref.current = instance;
            }
        }
    };
}
exports.mergeRefs = mergeRefs;
/**
 * Creates a named context, provider, and hook.
 *
 * @param options create context options
 */
function createContext(options = {}) {
    const { strict = true, errorMessage = 'useContext: `context` is undefined. Seems you forgot to wrap component within the Provider', name, } = options;
    const Context = react_1.default.createContext(undefined);
    Context.displayName = name;
    function useContext() {
        const context = react_1.default.useContext(Context);
        if (!context && strict) {
            throw new Error(errorMessage);
        }
        return context;
    }
    return [Context.Provider, useContext, Context];
}
exports.createContext = createContext;
