import React from 'react';
import { Collector } from '@music163/tango-boot';
import { isDeepEquals, isFunction, isNil, mergeRefs } from '../helpers';
const defaultShouldLoadData = () => true;
/**
 * 数据提供者
 */
class DataProviderBase extends React.Component {
    constructor() {
        super(...arguments);
        this.state = {
            data: undefined,
            loading: false,
            error: undefined,
        };
    }
    load() {
        const { shouldLoadData, loadData, payload } = this.props;
        const shouldLoad = shouldLoadData(payload);
        if (shouldLoad && isFunction(loadData)) {
            const ret = loadData(payload, { signal: this.controller.signal });
            // 如果无返回或者不是 promise 对象
            if (isNil(ret) || !ret.then) {
                this.updateData(ret);
                return;
            }
            this.setState({ loading: true });
            ret
                .then((data) => {
                this.updateData(data);
            })
                .catch((error) => {
                this.setState({ error });
            })
                .finally(() => {
                this.setState({ loading: false });
            });
        }
    }
    componentDidMount() {
        this.controller = new AbortController();
        this.load();
    }
    componentDidUpdate(prevProps) {
        if (!isDeepEquals(prevProps.payload, this.props.payload)) {
            this.load();
        }
    }
    componentWillUnmount() {
        this.controller.abort();
    }
    render() {
        const { children } = this.props;
        const { data, loading, error } = this.state;
        return React.createElement(React.Fragment, null, children === null || children === void 0 ? void 0 : children(data, { loading, error }));
    }
    updateData(data) {
        // const { model, formatter, onData } = this.props;
        const { formatter, onData } = this.props;
        if (isFunction(formatter)) {
            data = formatter(data);
        }
        this.setState({ data });
        if (isFunction(onData)) {
            onData(data);
        }
    }
}
DataProviderBase.defaultProps = {
    shouldLoadData: defaultShouldLoadData,
};
export const DataProvider = React.forwardRef((props, ref) => {
    return (React.createElement(Collector, Object.assign({}, props, { render: ({ setValue, ref: tangoRef }) => {
            return (React.createElement(DataProviderBase, Object.assign({}, props, { onData: (data) => {
                    setValue(data);
                }, ref: mergeRefs(ref, tangoRef) })));
        } })));
});
DataProvider.displayName = 'DataProvider';
