import React from 'react';
export function mergeRefs(...refs) {
    const filteredRefs = refs.filter(Boolean);
    if (!filteredRefs.length)
        return null;
    if (filteredRefs.length === 0)
        return filteredRefs[0];
    return (instance) => {
        for (const ref of filteredRefs) {
            if (typeof ref === 'function') {
                ref(instance);
            }
            else if (ref) {
                ref.current = instance;
            }
        }
    };
}
/**
 * Creates a named context, provider, and hook.
 *
 * @param options create context options
 */
export function createContext(options = {}) {
    const { strict = true, errorMessage = 'useContext: `context` is undefined. Seems you forgot to wrap component within the Provider', name, } = options;
    const Context = React.createContext(undefined);
    Context.displayName = name;
    function useContext() {
        const context = React.useContext(Context);
        if (!context && strict) {
            throw new Error(errorMessage);
        }
        return context;
    }
    return [Context.Provider, useContext, Context];
}
